@@ -14,6 +14,7 @@
 #endif
 #include "onnx/common/file_utils.h"
 #include "onnx/shape_inference/implementation.h"
+#include "onnxoptimizer/model_util.h"
 #include "onnxoptimizer/optimize.h"
 
 struct Config {
@@ -26,6 +27,26 @@ Config config;
 
 std::shared_ptr<const ModelExecutor> ModelExecutor::instance_ = nullptr;
 
+bool IsOfficialOp(const std::string& domain, const std::string& op) {
+  if (domain != "ai.onnx" && domain != "ai.onnx.ml" && !domain.empty()) {
+    return false;
+  }
+  // these experimental ops were in onnx default domain but are no
+  // longer supported by onnx now.
+  static std::set<std::string> experimental_ops = {"ATen",
+                                                   "Affine",
+                                                   "ConstantFill",
+                                                   "Crop",
+                                                   "DynamicSlice",
+                                                   "GRUUnit",
+                                                   "GivenTensorFill",
+                                                   "ImageScaler",
+                                                   "ParametricSoftplus",
+                                                   "Scale",
+                                                   "ScaledTanh"};
+  return experimental_ops.find(op) == experimental_ops.end();
+}
+
 bool IsDeterministic(const std::string& domain, const std::string& op) {
   // Copy from onnxruntime/core/optimizer/utils.cc
   constexpr std::array kOnnxDomainNonDeterministicOps{
@@ -336,7 +357,8 @@ GetConstantNodes(const onnx::ModelProto& model) {
   // node is already topo sorted
   for (const auto& node : model.graph().node()) {
     // clang-format off
-    if (IsDeterministic(node.domain(), node.name()) &&
+    if (IsOfficialOp(node.domain(), node.op_type()) &&
+        IsDeterministic(node.domain(), node.op_type()) &&
         !IsQDQ(node.domain(), node.name()) &&
         !HasSubgraph(node) &&
         !ProduceLargeTensor(model, node, config.tensor_size_threshold) &&
@@ -381,7 +403,7 @@ onnx::ModelProto _FoldConstant(const onnx::ModelProto& model) {
 }
 
 onnx::ModelProto Optimize(const onnx::ModelProto& model) {
-  return onnx::optimization::Optimize(model, config.optimizer_passes);
+  return onnx::optimization::OptimizeFixed(model, config.optimizer_passes);
 }
 
 template <typename T>
@@ -444,3 +466,16 @@ onnx::ModelProto Simplify(
   Check(sim_model);
   return sim_model;
 }
+
+void SimplifyPath(const std::string& in_path, const std::string& out_path,
+                  std::optional<std::vector<std::string>> skip_optimizers,
+                  bool constant_folding, bool shape_inference,
+                  size_t tensor_size_threshold) {
+  onnx::ModelProto model;
+  onnx::optimization::loadModel(&model, in_path, true);
+
+  model = Simplify(model, skip_optimizers, constant_folding, shape_inference,
+                   tensor_size_threshold);
+
+  onnx::optimization::saveModel(&model, out_path, true, "");
+}
